# Release notes

<!-- do not remove -->

## 0.0.3

### New Features

- skip archive download if extracted data exists ([#7](https://github.com/fastai/fastdownload/issues/7))


## 0.0.2

### New Features

- add `extract_key` param ([#5](https://github.com/fastai/fastdownload/issues/5))


## 0.0.1

### New Features

- Initial release

